package testy

import (
	"io"
)

type errWriter struct {
	count int
	err   error
}

var _ io.WriteCloser = &errWriter{}

func (w *errWriter) Write(p []byte) (int, error) {
	c := len(p)
	if c >= w.count {
		return w.count, w.err
	}
	w.count -= c
	return c, nil
}

func (w *errWriter) Close() error { return w.err }

// ErrorWriter returns a new io.Writer, which will accept count bytes
// (discarding them), then return err as an error. A call to Close() will
// also return err.
func ErrorWriter(count int, err error) io.WriteCloser {
	return &errWriter{count: count, err: err}
}
